@@ -5,7 +5,6 @@
 # b) If X is a fitted point process model (object of class "ppm" or "kppm"),
 # the simulated model is that model (by spatstat).
 # If testfuns is given, then also several different test functions can be calculated.
-#' @importFrom spatstat envelope
 funcs_from_X_and_funs <- function(X, nsim, testfuns=NULL, ...,
                                   savepatterns=FALSE, verbose=FALSE, calc_funcs=TRUE) {
   extraargs <- list(...)
@@ -19,25 +18,23 @@ funcs_from_X_and_funs <- function(X, nsim, testfuns=NULL, ...,
   # Simulations
   # Calculate the first test functions and generate simulations
   X.ls[[1]] <- do.call(spatstat::envelope, c(list(Y=X, nsim=nsim, simulate=NULL),
-                                        testfuns[[1]],
-                                        list(savefuns=TRUE, savepatterns=savepatterns, verbose=verbose),
-                                        extraargs))
+                          testfuns[[1]],
+                          list(savefuns=TRUE, savepatterns=savepatterns, verbose=verbose),
+                          extraargs))
   # More than one test function, calculate the rest if calc_funcs==TRUE
   if(calc_funcs & nfuns > 1) {
     simpatterns <- attr(X.ls[[1]], "simpatterns")
     for(i in 2:nfuns) {
       X.ls[[i]] <- do.call(spatstat::envelope, c(list(Y=X, nsim=nsim, simulate=simpatterns),
-                                            testfuns[[i]],
-                                            list(savefuns=TRUE, savepatterns=FALSE, verbose=verbose),
-                                            extraargs))
+                              testfuns[[i]],
+                              list(savefuns=TRUE, savepatterns=FALSE, verbose=verbose),
+                              extraargs))
     }
   }
   X.ls
 }
 
 # A helper function to perform simulations for the GET.composite
-#' @importFrom spatstat is.ppm is.kppm is.lppm is.slrm
-#' @importFrom spatstat is.ppp
 #' @importFrom stats update
 #' @importFrom parallel mclapply
 adj.simulate <- function(X, nsim = 499, nsimsub = nsim,
@@ -114,13 +111,13 @@ GE.attr <- function(x, name = "p", ...) {
 # @inheritParams GET.composite
 adj.GET_helper <- function(curve_sets, type, alpha, alternative, ties, probs, MrkvickaEtal2017, ..., save.envelope=FALSE) {
   if(length(curve_sets) > 1 & MrkvickaEtal2017 & type %in% c("st", "qdir")) {
-    global_envtest <- combined_scaled_MAD_envelope(curve_sets, type=type, alpha=alpha, probs=probs, ...)
+    global_envtest <- combined_scaled_MAD_envelope_test(curve_sets, type=type, alpha=alpha, probs=probs, ...)
   }
   else {
     global_envtest <- global_envelope_test(curve_sets, type=type, alpha=alpha,
                                            alternative=alternative, ties=ties, probs=probs, ...)
   }
-  res <- structure(list(stat = as.numeric(GE.attr(global_envtest, "k")[1]), pval = GE.attr(global_envtest, "p")),
+  res <- structure(list(stat = as.numeric(GE.attr(global_envtest, "M")[1]), pval = GE.attr(global_envtest, "p")),
                    class = "adj_GET_helper")
   if(save.envelope) attr(res, "envelope_test") <- global_envtest
   res
@@ -135,9 +132,9 @@ adj.GET_helper <- function(curve_sets, type, alpha, alternative, ties, probs, Mr
 #' \itemize{
 #' \item If \code{X.ls} is provided, then the global envelope test is calculated based on
 #' functions in these objects. \code{X} should be a \code{curve_set} (see \code{\link{create_curve_set}})
-#' or an \code{\link[spatstat]{envelope}} object including the observed function and simulations
+#' or an \code{envelope} object of \pkg{spatstat} including the observed function and simulations
 #' from the tested model. \code{X.ls} should be a list of \code{curve_set} or
-#' \code{\link[spatstat]{envelope}} objects, where each component contains an "observed"
+#' envelope (of R library \pkg{spatstat}) objects, where each component contains an "observed"
 #' function f that has been simulated from the model fitted to the data and the simulations
 #' that have been obtained from the same model that has been fitted to the "observed" f.
 #' The user has the responsibility that the functions have been generated correctly,
@@ -151,17 +148,17 @@ adj.GET_helper <- function(curve_sets, type, alpha, alternative, ties, probs, Mr
 #' not a function), \code{calcfun} can be used to specify how to calculate the function from
 #' \code{X} and from simulations generated by \code{simfun}.
 #' Special attention is needed in the correct specification of the functions, see examples.
-#'  \item Otherwise, \code{X} should be either a fitted (point process) model object or a \code{\link{ppp}}
-#'   object of the R library \pkg{\link{spatstat}}.
+#'  \item Otherwise, \code{X} should be either a fitted (point process) model object or a \code{ppp}
+#'   object of the R library \pkg{spatstat}.
 #' \itemize{
-#'   \item If \code{X} is a fitted (point process) model object of the R library \pkg{\link{spatstat}},
+#'   \item If \code{X} is a fitted (point process) model object of the R library \pkg{spatstat},
 #' then the simulations from this model are generated and summary functions for testing calculated
-#' by \code{\link[spatstat]{envelope}}. Which summary function to use and how to calculate it,
-#' can be passed to \code{\link[spatstat]{envelope}} either in \code{...} or \code{testfuns}.
-#' Unless otherwise specified the default function of \code{\link[spatstat]{envelope}},
+#' by the \code{envelope} function of \pkg{spatstat}. Which summary function to use and how to calculate it,
+#' can be passed to \code{envelope} either in \code{...} or \code{testfuns}.
+#' Unless otherwise specified the default function of \code{envelope},
 #' i.g. the K-function, is used. The argument \code{testfuns} should be used to specify the
 #' test functions in the case where one wants to base the test on several test functions.
-#'   \item If \code{X} is a \code{\link[spatstat]{ppp}} object, then \code{\link[spatstat]{envelope}}
+#'   \item If \code{X} is a \code{ppp} object of \pkg{spatstat}, then the \code{envelope} function
 #' is used for simulations and model fitting and the complete spatial randomness (CSR) is tested
 #' (with intensity parameter).
 #' }
@@ -175,11 +172,11 @@ adj.GET_helper <- function(curve_sets, type, alpha, alternative, ties, probs, Mr
 #' See examples also in \code{\link{saplings}}.
 #'
 #' @param X An object containing the data in some form.
-#' A \code{curve_set} (see \code{\link{create_curve_set}}) or an \code{\link[spatstat]{envelope}}
-#' object, as the \code{curve_sets} argument of \code{\link{global_envelope_test}}
+#' A \code{curve_set} (see \code{\link{create_curve_set}}) or an \code{envelope}
+#' object (of the \pkg{spatstat} package), as the \code{curve_sets} argument of \code{\link{global_envelope_test}}
 #' (need to provide \code{X.ls}), or
-#' a fitted point process model of \pkg{\link{spatstat}} (e.g. object of class \code{\link[spatstat]{ppm}} or
-#' \code{\link[spatstat]{kppm}}), or a point pattern object of class \code{\link[spatstat]{ppp}},
+#' a fitted point process model of \pkg{spatstat} (e.g. object of class \code{ppm} or
+#' \code{kppm}), or a point pattern object of class \code{ppp} of \pkg{spatstat},
 #' or another data object (need to provide \code{simfun}, \code{fitfun}, \code{calcfun}).
 #' @param X.ls A list of objects as \code{curve_sets} argument of \code{\link{global_envelope_test}},
 #' giving the second stage simulations, see details.
@@ -198,26 +195,26 @@ adj.GET_helper <- function(curve_sets, type, alpha, alternative, ties, probs, Mr
 #' The default is the identity function, i.e. the simulations from the model are functions themselves.
 #' The use of \code{calcfun} is still experimental. Preferably provide \code{X} and
 #' \code{X.ls} instead, if \code{X} is not a point pattern or fitted point process model object
-#' of \pkg{\link{spatstat}}.
-#' @param testfuns A list of lists of parameters to be passed to \code{\link[spatstat]{envelope}}
-#' if \code{X} is a point pattern of a fitted point process model of \pkg{\link{spatstat}}.
+#' of \pkg{spatstat}.
+#' @param testfuns A list of lists of parameters to be passed to the \code{envelope} function of \pkg{spatstat}
+#' if \code{X} is a point pattern of a fitted point process model of \pkg{spatstat}.
 #' A list of parameters should be provided for each test function that is to be used in the
 #' combined test.
-#' @param ... Additional parameters to \code{\link[spatstat]{envelope}} in the case where only one test
-#' function is used. In that case, this is an alternative to providing the parameters in the argument
-#' testfuns. If \code{\link[spatstat]{envelope}} is also used to generate simulations under the null
+#' @param ... Additional parameters to the \code{envelope} function of \pkg{spatstat} in the case where
+#' only one test function is used. In that case, this is an alternative to providing the parameters in the
+#' argument testfuns. If \code{envelope} is also used to generate simulations under the null
 #' hypothesis (if simfun not provided), then also recall to specify how to generate the simulations.
 #' @inheritParams global_envelope_test
 #' @param r_min The minimum argument value to include in the test.
 #' @param r_max The maximum argument value to include in the test.
-#' in calculating functions by \code{\link[spatstat]{envelope}}.
+#' in calculating functions by the \code{envelope} function of \pkg{spatstat}.
 #' @param take_residual Logical. If TRUE (needed for visual reasons only) the mean of the simulated
 #' functions is reduced from the functions in each first and second stage test.
 #' @param save.cons.envelope Logical flag indicating whether to save the unadjusted envelope test results.
 #' @param savefuns Logical flag indicating whether to save all the simulated function values.
-#' Similar to the same argument of \code{\link[spatstat]{envelope}}.
+#' Similar to the same argument of the \code{envelope} function of \pkg{spatstat}.
 #' @param verbose Logical flag indicating whether to print progress reports during the simulations.
-#' Similar to the same argument of \code{\link[spatstat]{envelope}}.
+#' Similar to the same argument of \code{envelope} function of \pkg{spatstat}.
 #' @param MrkvickaEtal2017 Logical. If TRUE, type is "st" or "qdir" and several test functions are used,
 #' then the combined scaled MAD envelope presented in Mrkvička et al. (2017) is calculated. Otherwise,
 #' the two-step procedure described in \code{\link{global_envelope_test}} is used for combining the tests.
@@ -290,7 +287,7 @@ adj.GET_helper <- function(curve_sets, type, alpha, alternative, ties, probs, Mr
 #'   }
 #'   # Perform the adjusted test
 #'   res <- GET.composite(X=cset, X.ls=cset.ls, type='erl')
-#'   plot(res, xlab="NOx", ylab="Ecdf")
+#'   plot(res) + ggplot2::labs(x="NOx", y="Ecdf")
 #' }
 #'
 #' @examples
@@ -299,7 +296,8 @@ adj.GET_helper <- function(curve_sets, type, alpha, alternative, ties, probs, Mr
 #' # Test the fit of a Matern cluster process.
 #' \donttest{
 #' if(require("spatstat", quietly=TRUE)) {
-#'   data(saplings)
+#'   data("saplings")
+#'   saplings <- as.ppp(saplings, W=square(75))
 #'
 #'   # First choose the r-distances
 #'   rmin <- 0.3; rmax <- 10; rstep <- (rmax-rmin)/500
@@ -372,11 +370,11 @@ GET.composite <- function(X, X.ls = NULL,
   #----------------------------
   if(!is.null(X.ls)) {
     # Check dimensions of each curve_set and transform to curve_sets
-    if(class(X)[1] != "list") {
+    if(!(length(class(X)) == 1 && class(X) == "list")) {
       X <- list(X) # The observed curves (a list of curve_set objects)
       X.ls <- lapply(X.ls, FUN=list) # The simulated curves (a list of lists of curve_set objects)
     }
-    picked_attr_ls <- lapply(X, FUN=pick_attributes, alternative=alt, type=type)
+    picked_attr_ls <- lapply(X, FUN=pick_attributes, alternative=alt)
     X <- check_curve_set_dimensions(X)
     X.ls <- lapply(X.ls, FUN = check_curve_set_dimensions)
     # Check equality of dimensions over repetitions
@@ -394,7 +392,7 @@ GET.composite <- function(X, X.ls = NULL,
     tmp <- adj.simulate(X=X, nsim=nsim, nsimsub=nsimsub,
                        simfun=simfun, fitfun=fitfun, calcfun=calcfun, testfuns=testfuns, ...,
                        verbose=verbose, mc.cores=mc.cores)
-    picked_attr_ls <- lapply(tmp$X, FUN=pick_attributes, alternative=alt, type=type)
+    picked_attr_ls <- lapply(tmp$X, FUN=pick_attributes, alternative=alt)
     X <- check_curve_set_dimensions(tmp$X)
     X.ls <- lapply(tmp$X.ls, FUN = check_curve_set_dimensions)
   }
@@ -438,7 +436,7 @@ GET.composite <- function(X, X.ls = NULL,
     res <- attr(obs_res, "envelope_test")
     #-- The rank test at the second level
     # Calculate the critical rank / alpha
-    kalpha_star <- quantile(stats, probs=alpha, type=1)
+    Malpha_star <- quantile(stats, probs=alpha, type=1)
     all_curves <- data_and_sim_curves(attr(res, "level2_curve_set")) # the second step "curves"
     nr <- ncol(all_curves)
     Nfunc <- nrow(all_curves)
@@ -446,14 +444,14 @@ GET.composite <- function(X, X.ls = NULL,
     UB <- array(0, nr)
     for(i in 1:nr){
       Hod <- sort(all_curves[,i])
-      LB[i]<- Hod[kalpha_star]
-      UB[i]<- Hod[Nfunc-kalpha_star+1]
+      LB[i]<- Hod[Malpha_star]
+      UB[i]<- Hod[Nfunc-Malpha_star+1]
     }
-    # -> kalpha_star, LB, UB of the (second level) rank test
+    # -> Malpha_star, LB, UB of the (second level) rank test
     # Update res object with adjusted values
     attr(res, "level2_ge")$lo <- LB
     attr(res, "level2_ge")$hi <- UB
-    attr(attr(res, "level2_ge"), "k_alpha_star") <- kalpha_star # Add kalpha_star
+    attr(attr(res, "level2_ge"), "M_alpha_star") <- Malpha_star # Add Malpha_star
     # Re-calculate the new qdir/st envelopes
     envchars <- combined_scaled_MAD_bounding_curves_chars(X, type = type)
     central_curves_ls <- lapply(X, function(x) get_T_0(x))
@@ -468,7 +466,7 @@ GET.composite <- function(X, X.ls = NULL,
   else { # Otherwise, the ERL test is used at the second level of a combined test
     if(type == "rank" & nfuns == 1) {
       # Calculate the critical rank (instead of alpha) and the adjusted envelope following Myllymäki et al. (2017)
-      kalpha_star <- quantile(stats, probs=alpha, type=1)
+      Malpha_star <- quantile(stats, probs=alpha, type=1)
       all_curves <- data_and_sim_curves(X[[1]]) # all the functions
       nr <- length(X[[1]]$r)
       Nfunc <- nrow(all_curves)
@@ -476,15 +474,15 @@ GET.composite <- function(X, X.ls = NULL,
       UB <- array(0, nr)
       for(i in 1:nr){
         Hod <- sort(all_curves[,i])
-        LB[i]<- Hod[kalpha_star]
-        UB[i]<- Hod[Nfunc-kalpha_star+1]
+        LB[i]<- Hod[Malpha_star]
+        UB[i]<- Hod[Nfunc-Malpha_star+1]
       }
       # For getting automatically an global_envelope object, first call central_region
       res <- central_region(X, type=type, coverage=1-alpha, alternative=alt, central="mean")
       # Update res object with adjusted values
       res$lo <- LB
       res$hi <- UB
-      attr(res, "k_alpha_star") <- kalpha_star # Add kalpha_star
+      attr(res, "M_alpha_star") <- Malpha_star # Add Malpha_star
     }
     else {
       alpha_star <- quantile(pvals, probs=alpha, type=1)
@@ -499,8 +497,8 @@ GET.composite <- function(X, X.ls = NULL,
         attr(res, "alpha_star") <- alpha_star
       }
       else {
-        attr(attr(res, "level2_ge"), "alpha") <- alpha
-        attr(attr(res, "level2_ge"), "alpha_star") <- alpha_star
+        attr(res, "alpha") <- attr(attr(res, "level2_ge"), "alpha") <- alpha
+        attr(res, "alpha_star") <- attr(attr(res, "level2_ge"), "alpha_star") <- alpha_star
       }
     }
   }
@@ -514,7 +512,7 @@ GET.composite <- function(X, X.ls = NULL,
       for(i in 1:nfuns)
         attr(res[[i]], n) <- picked_attr_ls[[i]][[n]]
   }
-  attr(res, "method") <- "Adjusted global envelope test" # Change method name
+  attr(res, "method") <- "Adjusted global test" # Change method name
   attr(res, "call") <- match.call() # Update "call" attribute
   # Additions
   if(savefuns) {
